# NamedStyles

The named styles. Paragraphs in the document can inherit their TextStyle and ParagraphStyle from these named styles.

**Type:** object

## Properties

- **styles** (array of [NamedStyle](namedstyle.md)): The named styles. There's an entry for each of the possible named style types.
